@@ -17,19 +17,15 @@ INSERT INTO dem.message_inbox (
 ) VALUES (
 	(select pk from dem.staff where db_user = 'any-doc'),
 	(select pk_type from dem.v_inbox_item_type where type = 'memo' and category = 'administrative'),
-	'Release Notes for GNUmed 1.1.12 (database v16.12)',
-	'GNUmed 1.1.12 Release Notes:
+	'Release Notes for GNUmed 1.1.15 (database v16.15)',
+	'GNUmed 1.1.15 Release Notes:
 
-	1.1.12
+	1.1.15
 
-FIX: exception with certain invalid placeholders [thanks S.Reus]
-FIX: add missing encoding detection [thanks Andrew]
-FIX: broken health issue creation from its PRW [thanks S.Reus]
+FIX: exception on removing components from branded drug [thanks S.Hilbert]
 
-IMPROVED: robustify os.startfile() use [thanks S.Hilbert]
-IMPROVED: robustify auto-setting of encounter.last_affirmed
-IMPROVED: robustify validity checks of cFuzzyTimestampInput [thanks S.Reus]
-IMPROVED: overly eager page number collision check [thanks S.Hilbert]
+IMPROVED: bring back [OK] button on editing progress notes [thanks J.Busser]
+IMPROVED: patient search trying to pin down merge issue
 ');
 
 -- --------------------------------------------------------------
